@@ -52,6 +52,7 @@ def bytes_to_int(bytes):
 def int_to_biguint(n):
     """
     Convert integer to :obj:`protos.BigUint`
+
     Args:
         n(int): number to be converted
 
@@ -67,6 +68,32 @@ def int_to_biguint(n):
     return protos.BigUint(value=int_to_bytes(n))
 
 
+def token_to_biguint(token):
+    r"""
+    Convert token to smallest unit, then to bigUint
+
+    Args:
+        token(num): token value
+
+    Returns:
+        :obj:`BigUint`
+
+    Examples:
+        >>> token_to_biguint(1)
+        value: "#\206\362o\301\000\000"
+
+    """
+    return int_to_biguint(int(token*1e+16))
+
+
+def token_to_unit(token):
+    return int(token*1e16)
+
+
+def unit_to_token(unit):
+    return int(unit/1e16)
+
+
 def biguint_to_int(biguint):
     """
     Convert :obj:`BigUint` to integer
